@@ -1,5 +1,5 @@
-/* SPDX-License-Identifier: GPL-2.0
- *
+// SPDX-License-Identifier: GPL-2.0
+/*
  * Copyright (C) 2015-2018 Jason A. Donenfeld <Jason@zx2c4.com>. All Rights Reserved.
  */
 
@@ -7,27 +7,27 @@
 #include "peer.h"
 #include "noise.h"
 
-static inline struct hlist_head *pubkey_bucket(struct pubkey_hashtable *table,
+static struct hlist_head *pubkey_bucket(struct pubkey_hashtable *table,
 					const u8 pubkey[NOISE_PUBLIC_KEY_LEN])
 {
 	/* siphash gives us a secure 64bit number based on a random key. Since
 	 * the bits are uniformly distributed, we can then mask off to get the
 	 * bits we need.
 	 */
-	return &table->hashtable[
-		siphash(pubkey, NOISE_PUBLIC_KEY_LEN, &table->key) &
-			(HASH_SIZE(table->hashtable) - 1)];
+	const u64 hash = siphash(pubkey, NOISE_PUBLIC_KEY_LEN, &table->key);
+
+	return &table->hashtable[hash & (HASH_SIZE(table->hashtable) - 1)];
 }
 
-void pubkey_hashtable_init(struct pubkey_hashtable *table)
+void wg_pubkey_hashtable_init(struct pubkey_hashtable *table)
 {
 	get_random_bytes(&table->key, sizeof(table->key));
 	hash_init(table->hashtable);
 	mutex_init(&table->lock);
 }
 
-void pubkey_hashtable_add(struct pubkey_hashtable *table,
-			  struct wireguard_peer *peer)
+void wg_pubkey_hashtable_add(struct pubkey_hashtable *table,
+			     struct wg_peer *peer)
 {
 	mutex_lock(&table->lock);
 	hlist_add_head_rcu(&peer->pubkey_hash,
@@ -35,8 +35,8 @@ void pubkey_hashtable_add(struct pubkey_hashtable *table,
 	mutex_unlock(&table->lock);
 }
 
-void pubkey_hashtable_remove(struct pubkey_hashtable *table,
-			     struct wireguard_peer *peer)
+void wg_pubkey_hashtable_remove(struct pubkey_hashtable *table,
+				struct wg_peer *peer)
 {
 	mutex_lock(&table->lock);
 	hlist_del_init_rcu(&peer->pubkey_hash);
@@ -44,28 +44,28 @@ void pubkey_hashtable_remove(struct pubkey_hashtable *table,
 }
 
 /* Returns a strong reference to a peer */
-struct wireguard_peer *
-pubkey_hashtable_lookup(struct pubkey_hashtable *table,
-			const u8 pubkey[NOISE_PUBLIC_KEY_LEN])
+struct wg_peer *
+wg_pubkey_hashtable_lookup(struct pubkey_hashtable *table,
+			   const u8 pubkey[NOISE_PUBLIC_KEY_LEN])
 {
-	struct wireguard_peer *iter_peer, *peer = NULL;
+	struct wg_peer *iter_peer, *peer = NULL;
 
 	rcu_read_lock_bh();
-	hlist_for_each_entry_rcu_bh (iter_peer, pubkey_bucket(table, pubkey),
-				     pubkey_hash) {
+	hlist_for_each_entry_rcu_bh(iter_peer, pubkey_bucket(table, pubkey),
+				    pubkey_hash) {
 		if (!memcmp(pubkey, iter_peer->handshake.remote_static,
 			    NOISE_PUBLIC_KEY_LEN)) {
 			peer = iter_peer;
 			break;
 		}
 	}
-	peer = peer_get_maybe_zero(peer);
+	peer = wg_peer_get_maybe_zero(peer);
 	rcu_read_unlock_bh();
 	return peer;
 }
 
-static inline struct hlist_head *index_bucket(struct index_hashtable *table,
-					      const __le32 index)
+static struct hlist_head *index_bucket(struct index_hashtable *table,
+				       const __le32 index)
 {
 	/* Since the indices are random and thus all bits are uniformly
 	 * distributed, we can find its bucket simply by masking.
@@ -74,7 +74,7 @@ static inline struct hlist_head *index_bucket(struct index_hashtable *table,
 				 (HASH_SIZE(table->hashtable) - 1)];
 }
 
-void index_hashtable_init(struct index_hashtable *table)
+void wg_index_hashtable_init(struct index_hashtable *table)
 {
 	hash_init(table->hashtable);
 	spin_lock_init(&table->lock);
@@ -104,8 +104,8 @@ void index_hashtable_init(struct index_hashtable *table)
  * is another thing to consider moving forward.
  */
 
-__le32 index_hashtable_insert(struct index_hashtable *table,
-			      struct index_hashtable_entry *entry)
+__le32 wg_index_hashtable_insert(struct index_hashtable *table,
+				 struct index_hashtable_entry *entry)
 {
 	struct index_hashtable_entry *existing_entry;
 
@@ -118,9 +118,9 @@ __le32 index_hashtable_insert(struct index_hashtable *table,
 search_unused_slot:
 	/* First we try to find an unused slot, randomly, while unlocked. */
 	entry->index = (__force __le32)get_random_u32();
-	hlist_for_each_entry_rcu_bh (existing_entry,
-				     index_bucket(table, entry->index),
-				     index_hash) {
+	hlist_for_each_entry_rcu_bh(existing_entry,
+				    index_bucket(table, entry->index),
+				    index_hash) {
 		if (existing_entry->index == entry->index)
 			/* If it's already in use, we continue searching. */
 			goto search_unused_slot;
@@ -130,9 +130,9 @@ search_unused_slot:
 	 * that nobody else stole it from us.
 	 */
 	spin_lock_bh(&table->lock);
-	hlist_for_each_entry_rcu_bh (existing_entry,
-				     index_bucket(table, entry->index),
-				     index_hash) {
+	hlist_for_each_entry_rcu_bh(existing_entry,
+				    index_bucket(table, entry->index),
+				    index_hash) {
 		if (existing_entry->index == entry->index) {
 			spin_unlock_bh(&table->lock);
 			/* If it was stolen, we start over. */
@@ -151,9 +151,9 @@ search_unused_slot:
 	return entry->index;
 }
 
-bool index_hashtable_replace(struct index_hashtable *table,
-			     struct index_hashtable_entry *old,
-			     struct index_hashtable_entry *new)
+bool wg_index_hashtable_replace(struct index_hashtable *table,
+				struct index_hashtable_entry *old,
+				struct index_hashtable_entry *new)
 {
 	if (unlikely(hlist_unhashed(&old->index_hash)))
 		return false;
@@ -172,8 +172,8 @@ bool index_hashtable_replace(struct index_hashtable *table,
 	return true;
 }
 
-void index_hashtable_remove(struct index_hashtable *table,
-			    struct index_hashtable_entry *entry)
+void wg_index_hashtable_remove(struct index_hashtable *table,
+			       struct index_hashtable_entry *entry)
 {
 	spin_lock_bh(&table->lock);
 	hlist_del_init_rcu(&entry->index_hash);
@@ -182,15 +182,15 @@ void index_hashtable_remove(struct index_hashtable *table,
 
 /* Returns a strong reference to a entry->peer */
 struct index_hashtable_entry *
-index_hashtable_lookup(struct index_hashtable *table,
-		       const enum index_hashtable_type type_mask,
-		       const __le32 index, struct wireguard_peer **peer)
+wg_index_hashtable_lookup(struct index_hashtable *table,
+			  const enum index_hashtable_type type_mask,
+			  const __le32 index, struct wg_peer **peer)
 {
 	struct index_hashtable_entry *iter_entry, *entry = NULL;
 
 	rcu_read_lock_bh();
-	hlist_for_each_entry_rcu_bh (iter_entry, index_bucket(table, index),
-				     index_hash) {
+	hlist_for_each_entry_rcu_bh(iter_entry, index_bucket(table, index),
+				    index_hash) {
 		if (iter_entry->index == index) {
 			if (likely(iter_entry->type & type_mask))
 				entry = iter_entry;
@@ -198,7 +198,7 @@ index_hashtable_lookup(struct index_hashtable *table,
 		}
 	}
 	if (likely(entry)) {
-		entry->peer = peer_get_maybe_zero(entry->peer);
+		entry->peer = wg_peer_get_maybe_zero(entry->peer);
 		if (likely(entry->peer))
 			*peer = entry->peer;
 		else
